import React, { useMemo } from 'react';
import { View, StyleSheet, Pressable, Text } from 'react-native';
import { useCalendarContext } from '../calendar-context';
import { getParsedDate, getMonthsArray, cn } from '../utils';
import { CONTAINER_HEIGHT } from '../enums';
const Months = () => {
  var _getMonthsArray;
  const {
    currentDate,
    onSelectMonth,
    styles,
    classNames,
    components,
    containerHeight = CONTAINER_HEIGHT,
    monthsFormat
  } = useCalendarContext();
  const style = useMemo(() => createDefaultStyles(containerHeight), [containerHeight]);
  const {
    month
  } = getParsedDate(currentDate);
  const containerStyle = StyleSheet.flatten([defaultStyles.container, styles === null || styles === void 0 ? void 0 : styles.months]);
  return /*#__PURE__*/React.createElement(View, {
    style: containerStyle,
    testID: "month-selector"
  }, /*#__PURE__*/React.createElement(View, {
    style: defaultStyles.months
  }, (_getMonthsArray = getMonthsArray()) === null || _getMonthsArray === void 0 ? void 0 : _getMonthsArray.map((item, index) => {
    const isSelected = index === month;
    const activeItemStyle = isSelected ? styles === null || styles === void 0 ? void 0 : styles.selected_month : {};
    const textStyle = isSelected ? styles === null || styles === void 0 ? void 0 : styles.selected_month_label : {};
    const containerClassName = cn(isSelected ? classNames === null || classNames === void 0 ? void 0 : classNames.selected_month : classNames === null || classNames === void 0 ? void 0 : classNames.month);
    const textClassName = cn(isSelected ? classNames === null || classNames === void 0 ? void 0 : classNames.selected_month_label : classNames === null || classNames === void 0 ? void 0 : classNames.month_label);
    return /*#__PURE__*/React.createElement(View, {
      key: index,
      style: style.monthCell
    }, components !== null && components !== void 0 && components.Month ? /*#__PURE__*/React.createElement(Pressable, {
      onPress: () => onSelectMonth(index),
      accessibilityRole: "button",
      accessibilityLabel: item.name,
      style: defaultStyles.month
    }, components.Month({
      ...item,
      isSelected
    })) : /*#__PURE__*/React.createElement(Pressable, {
      onPress: () => onSelectMonth(index),
      accessibilityRole: "button",
      accessibilityLabel: item.name,
      style: [defaultStyles.month, styles === null || styles === void 0 ? void 0 : styles.month, activeItemStyle],
      className: containerClassName
    }, /*#__PURE__*/React.createElement(Text, {
      key: index,
      style: textStyle,
      className: textClassName
    }, monthsFormat === 'full' ? item.name : item.short)));
  })));
};
const defaultStyles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
    justifyContent: 'center'
  },
  months: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  },
  month: {
    flex: 1,
    margin: 2,
    alignItems: 'center',
    justifyContent: 'center'
  }
});
const createDefaultStyles = containerHeight => StyleSheet.create({
  monthCell: {
    width: `${100 / 3}%`,
    height: containerHeight / 6
  }
});
export default Months;
//# sourceMappingURL=months.js.map